@@ -10,7 +10,7 @@
         auto * output = dynamic_cast< ModelSEIRMixing<TSeq> * >( (model) ); \
         /*Using the [[assume(...)]] to avoid the compiler warning \
         if the standard is C++23 or later */ \
-        [[assume((output) != nullptr)]]
+        [[assume((output) != nullptr)]];
 #else
     // C++17 or C++20
     #define GET_MODEL(model, output) \
@@ -21,18 +21,22 @@
 /**
  * @file seirentitiesconnected.hpp
  * @brief Template for a Susceptible-Exposed-Infected-Removed (SEIR) model with mixing
+ * 
+ * ![Model Diagram](../assets/img/seirmixing.png)
+ * 
+ * @ingroup mixing_models
  */
 template<typename TSeq = EPI_DEFAULT_TSEQ>
-class ModelSEIRMixing : public epiworld::Model<TSeq> 
+class ModelSEIRMixing : public epiworld::Model<TSeq>
 {
 private:
-    
-    // Vector of vectors of infected agents     
+
+    // Vector of vectors of infected agents
     std::vector< size_t > infected;
 
     // Number of infected agents in each group
     std::vector< size_t > n_infected_per_group;
-    
+
     // Where the agents start in the `infected` vector
     std::vector< size_t > entity_indices;
 
@@ -57,7 +61,7 @@ public:
     static const int RECOVERED   = 3;
 
     ModelSEIRMixing() {};
-    
+
     /**
      * @brief Constructs a ModelSEIRMixing object.
      *
@@ -83,7 +87,7 @@ public:
         epiworld_double recovery_rate,
         std::vector< double > contact_matrix
     );
-    
+
     /**
      * @brief Constructs a ModelSEIRMixing object.
      *
@@ -141,7 +145,7 @@ inline void ModelSEIRMixing<TSeq>::update_infected_list()
     auto & agents = Model<TSeq>::get_agents();
 
     std::fill(n_infected_per_group.begin(), n_infected_per_group.end(), 0u);
-    
+
     for (auto & a : agents)
     {
 
@@ -222,11 +226,11 @@ inline size_t ModelSEIRMixing<TSeq>::sample_agents(
                 continue;
 
             sampled_agents[samp_id++] = a.get_id();
-            
+
         }
 
     }
-    
+
     return samp_id;
 
 }
@@ -248,7 +252,7 @@ template<typename TSeq>
 inline void ModelSEIRMixing<TSeq>::reset()
 {
 
-    Model<TSeq>::reset();   
+    Model<TSeq>::reset();
 
     // Checking contact matrix's rows add to one
     size_t nentities = this->entities.size();
@@ -305,15 +309,15 @@ inline void ModelSEIRMixing<TSeq>::reset()
             ;
 
     }
-    
+
     // Adjusting contact rate
     adjusted_contact_rate.clear();
     adjusted_contact_rate.resize(this->entities.size(), 0.0);
 
     for (size_t i = 0u; i < this->entities.size(); ++i)
     {
-                
-        adjusted_contact_rate[i] = 
+
+        adjusted_contact_rate[i] =
             Model<TSeq>::get_param("Contact rate") /
                 static_cast< epiworld_double > (this->get_entity(i).size());
 
@@ -333,14 +337,14 @@ inline void ModelSEIRMixing<TSeq>::reset()
 template<typename TSeq>
 inline Model<TSeq> * ModelSEIRMixing<TSeq>::clone_ptr()
 {
-    
+
     ModelSEIRMixing<TSeq> * ptr = new ModelSEIRMixing<TSeq>(
         *dynamic_cast<const ModelSEIRMixing<TSeq>*>(this)
         );
 
     #if __cplusplus >= 202302L
         // C++23 or later
-        [[assume(ptr != nullptr)]]
+        [[assume(ptr != nullptr)]];
     #else
         // C++17 or C++20
         assert(ptr != nullptr); // Use assert for runtime checks
@@ -353,7 +357,7 @@ inline Model<TSeq> * ModelSEIRMixing<TSeq>::clone_ptr()
 
 /**
  * @brief Template for a Susceptible-Exposed-Infected-Removed (SEIR) model
- * 
+ *
  * @param model A Model<TSeq> object where to set up the SIR.
  * @param vname std::string Name of the virus
  * @param prevalence Initial prevalence (proportion)
@@ -389,7 +393,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
             // Downcasting to retrieve the sampler attached to the
             // class
             GET_MODEL(m, m_down);
-            
+
             size_t ndraws = m_down->sample_agents(p, m_down->sampled_agents);
 
             #ifdef EPI_DEBUG
@@ -398,7 +402,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
 
             if (ndraws == 0u)
                 return;
-            
+
             // Drawing from the set
             int nviruses_tmp = 0;
             for (size_t n = 0u; n < ndraws; ++n)
@@ -414,14 +418,14 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
                         "Trying to add an extra element to a temporal array outside of the range."
                     );
                 #endif
-                    
-                /* And it is a function of susceptibility_reduction as well */ 
+
+                /* And it is a function of susceptibility_reduction as well */
                 m->array_double_tmp[nviruses_tmp] =
-                    (1.0 - p->get_susceptibility_reduction(v, m)) * 
-                    v->get_prob_infecting(m) * 
-                    (1.0 - neighbor.get_transmission_reduction(v, m)) 
-                    ; 
-            
+                    (1.0 - p->get_susceptibility_reduction(v, m)) *
+                    v->get_prob_infecting(m) *
+                    (1.0 - neighbor.get_transmission_reduction(v, m))
+                    ;
+
                 m->array_virus_tmp[nviruses_tmp++] = &(*v);
 
             }
@@ -438,7 +442,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
                 ModelSEIRMixing<TSeq>::EXPOSED
                 );
 
-            return; 
+            return;
 
         };
 
@@ -473,8 +477,8 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
                 const auto & v = p->get_virus();
 
                 // Recover
-                m->array_double_tmp[n_events++] = 
-                    1.0 - (1.0 - v->get_prob_recovery(m)) * (1.0 - p->get_recovery_enhancer(v, m)); 
+                m->array_double_tmp[n_events++] =
+                    1.0 - (1.0 - v->get_prob_recovery(m)) * (1.0 - p->get_recovery_enhancer(v, m));
 
                 #ifdef EPI_DEBUG
                 if (n_events == 0u)
@@ -489,7 +493,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
                 if (n_events == 0u)
                     return;
                 #endif
-                
+
 
                 // Running the roulette
                 int which = roulette(n_events, m);
@@ -514,7 +518,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
     model.add_param(transmission_rate, "Prob. Transmission");
     model.add_param(recovery_rate, "Prob. Recovery");
     model.add_param(avg_incubation_days, "Avg. Incubation days");
-    
+
     // state
     model.add_state("Susceptible", update_susceptible);
     model.add_state("Exposed", update_exposed_and_infected);
@@ -526,7 +530,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
     {
 
         GET_MODEL(m, m_down);
-        
+
         m_down->update_infected_list();
 
         return;
@@ -572,7 +576,7 @@ inline ModelSEIRMixing<TSeq>::ModelSEIRMixing(
     epiworld_double recovery_rate,
     std::vector< double > contact_matrix
     )
-{   
+{
 
     this->contact_matrix = contact_matrix;
 
